==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/de/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "letzten Dienstag",
	"field-year": "Jahr",
	"field-wed-relative+0": "diesen Mittwoch",
	"field-wed-relative+1": "nächsten Mittwoch",
	"field-minute": "Minute",
	"field-month-narrow-relative+-1": "letzten Monat",
	"field-tue-narrow-relative+0": "diesen Di.",
	"field-tue-narrow-relative+1": "nächsten Di.",
	"field-thu-short-relative+0": "diesen Do.",
	"field-day-short-relative+-1": "gestern",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "nächsten Do.",
	"field-day-relative+0": "heute",
	"field-day-short-relative+-2": "vorgestern",
	"field-day-relative+1": "morgen",
	"field-week-narrow-relative+0": "diese Woche",
	"field-day-relative+2": "übermorgen",
	"field-week-narrow-relative+1": "nächste Woche",
	"field-wed-narrow-relative+-1": "letzten Mi.",
	"field-year-narrow": "J",
	"field-year-narrow-relative+0": "dieses Jahr",
	"field-tue-relative+0": "diesen Dienstag",
	"field-year-narrow-relative+1": "nächstes Jahr",
	"field-tue-relative+1": "nächsten Dienstag",
	"field-second-short": "Sek.",
	"dayPeriods-format-narrow-am": "vm.",
	"dateFormatItem-MMMd": "d. MMM",
	"dayPeriods-format-abbr-am": "vorm.",
	"field-week-relative+0": "diese Woche",
	"field-month-relative+0": "diesen Monat",
	"field-week-relative+1": "nächste Woche",
	"field-month-relative+1": "nächsten Monat",
	"field-sun-narrow-relative+0": "diesen So.",
	"field-mon-short-relative+0": "diesen Mo.",
	"field-sun-narrow-relative+1": "nächsten So.",
	"field-mon-short-relative+1": "nächsten Mo.",
	"field-second-relative+0": "jetzt",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dayPeriods-standAlone-abbr-pm": "nachm.",
	"field-month-short": "Monat",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"field-day": "Tag",
	"field-year-relative+-1": "letztes Jahr",
	"dayPeriods-format-wide-am": "vorm.",
	"field-sat-short-relative+-1": "letzten Sa.",
	"field-hour-relative+0": "in dieser Stunde",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"field-wed-relative+-1": "letzten Mittwoch",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "letzten Sa.",
	"field-second": "Sekunde",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dayPeriods-standAlone-wide-pm": "nachm.",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "in dieser Stunde",
	"field-quarter": "Quartal",
	"field-week-short": "Woche",
	"field-day-narrow-relative+0": "heute",
	"field-day-narrow-relative+1": "morgen",
	"field-day-narrow-relative+2": "übermorgen",
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-tue-short-relative+0": "diesen Di.",
	"field-tue-short-relative+1": "nächsten Di.",
	"field-month-short-relative+-1": "letzten Monat",
	"field-mon-relative+-1": "letzten Montag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "Monat",
	"field-day-narrow": "Tag",
	"field-minute-short": "Min.",
	"field-dayperiod": "Tageshälfte",
	"field-sat-short-relative+0": "diesen Sa.",
	"field-sat-short-relative+1": "nächsten Sa.",
	"dayPeriods-format-narrow-pm": "nm.",
	"dateFormat-medium": "dd.MM.y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AM"
	],
	"dayPeriods-format-abbr-pm": "nachm.",
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"field-second-narrow": "Sek.",
	"field-mon-relative+0": "diesen Montag",
	"field-mon-relative+1": "nächsten Montag",
	"field-day-narrow-relative+-1": "gestern",
	"field-year-short": "Jahr",
	"field-day-narrow-relative+-2": "vorgestern",
	"field-quarter-relative+-1": "letztes Quartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dayPeriods-standAlone-narrow-am": "vorm.",
	"field-week-narrow-relative+-1": "letzte Woche",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"dayPeriods-format-wide-pm": "nachm.",
	"field-sat-relative+-1": "letzten Samstag",
	"dateTimeFormat-long": "{1} 'um' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-minute-narrow-relative+0": "in dieser Minute",
	"field-hour": "Stunde",
	"dateFormat-full": "EEEE, d. MMMM y G",
	"field-month-relative+-1": "letzten Monat",
	"field-quarter-short": "Quart.",
	"field-sat-narrow-relative+0": "diesen Sa.",
	"field-fri-relative+0": "diesen Freitag",
	"field-sat-narrow-relative+1": "nächsten Sa.",
	"field-fri-relative+1": "nächsten Freitag",
	"field-month-narrow-relative+0": "diesen Monat",
	"field-month-narrow-relative+1": "nächsten Monat",
	"field-sun-short-relative+0": "diesen So.",
	"field-sun-short-relative+1": "nächsten So.",
	"field-week-relative+-1": "letzte Woche",
	"field-minute-short-relative+0": "in dieser Minute",
	"field-quarter-relative+0": "dieses Quartal",
	"field-minute-relative+0": "in dieser Minute",
	"field-quarter-relative+1": "nächstes Quartal",
	"field-wed-short-relative+-1": "letzten Mi.",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"field-thu-short-relative+-1": "letzten Do.",
	"field-year-narrow-relative+-1": "letztes Jahr",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"field-mon-narrow-relative+-1": "letzten Mo.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "letzten Do.",
	"field-tue-narrow-relative+-1": "letzten Di.",
	"dateFormatItem-H": "HH 'Uhr'",
	"dateFormatItem-yyyy": "y G",
	"dayPeriods-standAlone-narrow-pm": "nachm.",
	"field-wed-short-relative+0": "diesen Mi.",
	"field-wed-short-relative+1": "nächsten Mi.",
	"field-sun-relative+-1": "letzten Sonntag",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dateTimeFormat-full": "{1} 'um' {0}",
	"field-weekday": "Wochentag",
	"field-day-short-relative+0": "heute",
	"field-quarter-narrow-relative+0": "dieses Quartal",
	"field-sat-relative+0": "diesen Samstag",
	"field-day-short-relative+1": "morgen",
	"field-quarter-narrow-relative+1": "nächstes Quartal",
	"field-sat-relative+1": "nächsten Samstag",
	"field-day-short-relative+2": "übermorgen",
	"field-week-short-relative+0": "diese Woche",
	"field-week-short-relative+1": "nächste Woche",
	"field-month-short-relative+0": "diesen Monat",
	"field-month-short-relative+1": "nächsten Monat",
	"dateFormatItem-MEd": "E, d.M.",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "diesen Do.",
	"field-thu-narrow-relative+1": "nächsten Do.",
	"field-sun-narrow-relative+-1": "letzten So.",
	"field-mon-short-relative+-1": "letzten Mo.",
	"field-thu-relative+0": "diesen Donnerstag",
	"field-thu-relative+1": "nächsten Donnerstag",
	"field-fri-short-relative+-1": "letzten Fr.",
	"field-thu-relative+-1": "letzten Donnerstag",
	"field-week": "Woche",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "diesen Mi.",
	"field-wed-narrow-relative+1": "nächsten Mi.",
	"field-quarter-narrow-relative+-1": "letztes Quartal",
	"field-year-short-relative+0": "dieses Jahr",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "nächstes Jahr",
	"field-fri-short-relative+0": "diesen Fr.",
	"field-fri-short-relative+1": "nächsten Fr.",
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-week-short-relative+-1": "letzte Woche",
	"field-hour-narrow-relative+0": "in dieser Stunde",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "Std.",
	"field-month-narrow": "M",
	"field-hour-narrow": "Std.",
	"field-fri-narrow-relative+-1": "letzten Fr.",
	"field-year-relative+0": "dieses Jahr",
	"field-year-relative+1": "nächstes Jahr",
	"field-fri-relative+-1": "letzten Freitag",
	"field-tue-short-relative+-1": "letzten Di.",
	"field-minute-narrow": "Min.",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-mon-narrow-relative+0": "diesen Mo.",
	"field-mon-narrow-relative+1": "nächsten Mo.",
	"field-year-short-relative+-1": "letztes Jahr",
	"field-zone": "Zeitzone",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "letzten So.",
	"field-day-relative+-1": "gestern",
	"dayPeriods-standAlone-abbr-am": "vorm.",
	"field-day-relative+-2": "vorgestern",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-sun-relative+0": "diesen Sonntag",
	"field-sun-relative+1": "nächsten Sonntag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "Tag",
	"field-week-narrow": "W",
	"field-era": "Epoche",
	"field-fri-narrow-relative+0": "diesen Fr.",
	"field-fri-narrow-relative+1": "nächsten Fr.",
	"dayPeriods-standAlone-wide-am": "vorm."
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/de/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "letzten Dienstag",
	"field-year": "Jahr",
	"field-wed-relative+0": "diesen Mittwoch",
	"field-wed-relative+1": "nächsten Mittwoch",
	"field-minute": "Minute",
	"field-month-narrow-relative+-1": "letzten Monat",
	"field-tue-narrow-relative+0": "diesen Di.",
	"field-tue-narrow-relative+1": "nächsten Di.",
	"field-thu-short-relative+0": "diesen Do.",
	"field-day-short-relative+-1": "gestern",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "nächsten Do.",
	"field-day-relative+0": "heute",
	"field-day-short-relative+-2": "vorgestern",
	"field-day-relative+1": "morgen",
	"field-week-narrow-relative+0": "diese Woche",
	"field-day-relative+2": "übermorgen",
	"field-week-narrow-relative+1": "nächste Woche",
	"field-wed-narrow-relative+-1": "letzten Mi.",
	"field-year-narrow": "J",
	"field-era-short": "Epoche",
	"field-year-narrow-relative+0": "dieses Jahr",
	"field-tue-relative+0": "diesen Dienstag",
	"field-year-narrow-relative+1": "nächstes Jahr",
	"field-tue-relative+1": "nächsten Dienstag",
	"field-weekdayOfMonth": "Wochentag",
	"field-second-short": "Sek.",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "WT",
	"field-week-relative+0": "diese Woche",
	"field-month-relative+0": "diesen Monat",
	"field-week-relative+1": "nächste Woche",
	"field-month-relative+1": "nächsten Monat",
	"field-sun-narrow-relative+0": "diesen So.",
	"field-mon-short-relative+0": "diesen Mo.",
	"field-sun-narrow-relative+1": "nächsten So.",
	"field-mon-short-relative+1": "nächsten Mo.",
	"field-second-relative+0": "jetzt",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"eraNames": [
		"AM"
	],
	"field-weekOfMonth": "Woche des Monats",
	"field-month-short": "Monat",
	"dateFormatItem-GyMMMEd": "E, d. MMM y G",
	"dateFormatItem-yyyyMd": "d.M.y GGGGG",
	"field-day": "Tag",
	"field-dayOfYear-short": "Tag des Jahres",
	"field-year-relative+-1": "letztes Jahr",
	"field-sat-short-relative+-1": "letzten Sa.",
	"field-hour-relative+0": "in dieser Stunde",
	"dateFormatItem-yyyyMEd": "E, d.M.y GGGGG",
	"field-wed-relative+-1": "letzten Mittwoch",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "letzten Sa.",
	"field-second": "Sekunde",
	"days-standAlone-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-hour-short-relative+0": "in dieser Stunde",
	"field-quarter": "Quartal",
	"field-week-short": "Woche",
	"field-day-narrow-relative+0": "heute",
	"field-day-narrow-relative+1": "morgen",
	"field-day-narrow-relative+2": "übermorgen",
	"quarters-standAlone-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"days-format-narrow": [
		"S",
		"M",
		"D",
		"M",
		"D",
		"F",
		"S"
	],
	"field-tue-short-relative+0": "diesen Di.",
	"field-tue-short-relative+1": "nächsten Di.",
	"field-month-short-relative+-1": "letzten Monat",
	"field-mon-relative+-1": "letzten Montag",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "Monat",
	"field-day-narrow": "Tag",
	"field-minute-short": "Min.",
	"field-dayperiod": "Tageshälfte",
	"field-sat-short-relative+0": "diesen Sa.",
	"field-sat-short-relative+1": "nächsten Sa.",
	"dateFormat-medium": "dd.MM.y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AM"
	],
	"dateFormatItem-yyyyM": "M.y GGGGG",
	"field-second-narrow": "Sek.",
	"field-mon-relative+0": "diesen Montag",
	"field-mon-relative+1": "nächsten Montag",
	"field-day-narrow-relative+-1": "gestern",
	"field-year-short": "Jahr",
	"field-day-narrow-relative+-2": "vorgestern",
	"field-quarter-relative+-1": "letztes Quartal",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-dayperiod-narrow": "Tagesh.",
	"field-week-narrow-relative+-1": "letzte Woche",
	"days-format-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-dayOfYear": "Tag des Jahres",
	"field-sat-relative+-1": "letzten Samstag",
	"dateTimeFormat-long": "{1} 'um' {0}",
	"dateFormatItem-Md": "d.M.",
	"field-minute-narrow-relative+0": "in dieser Minute",
	"field-hour": "Stunde",
	"months-format-wide": [
		"Tischri",
		"Cheschwan",
		"Kislew",
		"Tevet",
		"Schevat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijjar",
		"Siwan",
		"Tammus",
		"Aw",
		"Elul"
	],
	"dateFormat-full": "EEEE, d. MMMM y G",
	"field-month-relative+-1": "letzten Monat",
	"field-quarter-short": "Quart.",
	"field-sat-narrow-relative+0": "diesen Sa.",
	"field-fri-relative+0": "diesen Freitag",
	"field-sat-narrow-relative+1": "nächsten Sa.",
	"field-fri-relative+1": "nächsten Freitag",
	"field-month-narrow-relative+0": "diesen Monat",
	"field-month-narrow-relative+1": "nächsten Monat",
	"field-sun-short-relative+0": "diesen So.",
	"field-sun-short-relative+1": "nächsten So.",
	"field-week-relative+-1": "letzte Woche",
	"field-minute-short-relative+0": "in dieser Minute",
	"months-format-abbr": [
		"Tischri",
		"Cheschwan",
		"Kislew",
		"Tevet",
		"Schevat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijjar",
		"Siwan",
		"Tammus",
		"Aw",
		"Elul"
	],
	"field-quarter-relative+0": "dieses Quartal",
	"field-minute-relative+0": "in dieser Minute",
	"field-quarter-relative+1": "nächstes Quartal",
	"field-wed-short-relative+-1": "letzten Mi.",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"field-thu-short-relative+-1": "letzten Do.",
	"field-year-narrow-relative+-1": "letztes Jahr",
	"days-standAlone-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y G",
	"field-mon-narrow-relative+-1": "letzten Mo.",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "letzten Do.",
	"field-tue-narrow-relative+-1": "letzten Di.",
	"dateFormatItem-H": "HH 'Uhr'",
	"field-weekOfMonth-short": "W/M",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "diesen Mi.",
	"months-standAlone-wide": [
		"Tischri",
		"Cheschwan",
		"Kislew",
		"Tevet",
		"Schevat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijjar",
		"Siwan",
		"Tammus",
		"Aw",
		"Elul"
	],
	"field-wed-short-relative+1": "nächsten Mi.",
	"field-sun-relative+-1": "letzten Sonntag",
	"days-standAlone-abbr": [
		"So",
		"Mo",
		"Di",
		"Mi",
		"Do",
		"Fr",
		"Sa"
	],
	"dateTimeFormat-full": "{1} 'um' {0}",
	"months-format-abbr-leap": "Adar II",
	"field-weekday": "Wochentag",
	"field-day-short-relative+0": "heute",
	"field-quarter-narrow-relative+0": "dieses Quartal",
	"field-sat-relative+0": "diesen Samstag",
	"field-day-short-relative+1": "morgen",
	"field-quarter-narrow-relative+1": "nächstes Quartal",
	"field-sat-relative+1": "nächsten Samstag",
	"field-day-short-relative+2": "übermorgen",
	"field-week-short-relative+0": "diese Woche",
	"field-week-short-relative+1": "nächste Woche",
	"months-standAlone-abbr": [
		"Tischri",
		"Cheschwan",
		"Kislew",
		"Tevet",
		"Schevat",
		"Adar I",
		"Adar",
		"Nisan",
		"Ijjar",
		"Siwan",
		"Tammus",
		"Aw",
		"Elul"
	],
	"months-format-wide-leap": "Adar II",
	"field-dayOfYear-narrow": "T/J",
	"field-month-short-relative+0": "diesen Monat",
	"field-month-short-relative+1": "nächsten Monat",
	"field-weekdayOfMonth-short": "Wochentag",
	"dateFormatItem-MEd": "E, d.M.",
	"field-zone-narrow": "Zeitz.",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "diesen Do.",
	"field-thu-narrow-relative+1": "nächsten Do.",
	"field-sun-narrow-relative+-1": "letzten So.",
	"field-mon-short-relative+-1": "letzten Mo.",
	"field-thu-relative+0": "diesen Donnerstag",
	"field-thu-relative+1": "nächsten Donnerstag",
	"field-fri-short-relative+-1": "letzten Fr.",
	"field-thu-relative+-1": "letzten Donnerstag",
	"field-week": "Woche",
	"quarters-format-wide": [
		"1. Quartal",
		"2. Quartal",
		"3. Quartal",
		"4. Quartal"
	],
	"dateFormatItem-Ed": "E, d.",
	"field-wed-narrow-relative+0": "diesen Mi.",
	"field-wed-narrow-relative+1": "nächsten Mi.",
	"field-quarter-narrow-relative+-1": "letztes Quartal",
	"field-year-short-relative+0": "dieses Jahr",
	"field-dayperiod-short": "Tageshälfte",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "nächstes Jahr",
	"field-fri-short-relative+0": "diesen Fr.",
	"field-fri-short-relative+1": "nächsten Fr.",
	"days-standAlone-short": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-week-short-relative+-1": "letzte Woche",
	"months-standAlone-abbr-leap": "Adar II",
	"field-hour-narrow-relative+0": "in dieser Stunde",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "Std.",
	"field-zone-short": "Zeitzone",
	"field-month-narrow": "M",
	"field-hour-narrow": "Std.",
	"field-fri-narrow-relative+-1": "letzten Fr.",
	"field-year-relative+0": "dieses Jahr",
	"field-year-relative+1": "nächstes Jahr",
	"field-era-narrow": "E",
	"field-fri-relative+-1": "letzten Freitag",
	"eraNarrow": "AM",
	"field-tue-short-relative+-1": "letzten Di.",
	"field-minute-narrow": "Min.",
	"days-format-wide": [
		"Sonntag",
		"Montag",
		"Dienstag",
		"Mittwoch",
		"Donnerstag",
		"Freitag",
		"Samstag"
	],
	"field-mon-narrow-relative+0": "diesen Mo.",
	"field-mon-narrow-relative+1": "nächsten Mo.",
	"field-year-short-relative+-1": "letztes Jahr",
	"field-zone": "Zeitzone",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "Wo. des Monats",
	"field-weekday-narrow": "Wochent.",
	"months-standAlone-wide-leap": "Adar II",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "letzten So.",
	"field-day-relative+-1": "gestern",
	"field-day-relative+-2": "vorgestern",
	"field-weekday-short": "Wochentag",
	"days-format-abbr": [
		"So.",
		"Mo.",
		"Di.",
		"Mi.",
		"Do.",
		"Fr.",
		"Sa."
	],
	"field-sun-relative+0": "diesen Sonntag",
	"field-sun-relative+1": "nächsten Sonntag",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "Tag",
	"field-week-narrow": "W",
	"field-era": "Epoche",
	"field-fri-narrow-relative+0": "diesen Fr.",
	"field-fri-narrow-relative+1": "nächsten Fr."
}
//end v1.x content
);
